@@ -15,6 +15,8 @@ class DKConnection():
         r = requests.post('https://%s/v2/login' % hostname, data=payload)
         if r.text == 'Credentials are invalid':
             raise Exception
+        if "\n" in r.text or "\r" in r.text:
+            logger.error("Error: Platform returned invalid token." % (kitchen, recipe, variation))
         self.token = r.text
         self.headers =  {'content-type': 'application/json', 'authorization': 'bearer ' + self.token}
 
